==> RoughlyEnoughItems-4.1.12-unstable-sources.jar: me/shedaniel/rei/gui/ConfigReloadingScreen.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.gui;

import me.shedaniel.rei.api.RecipeHelper;
import net.minecraft.class_1074;
import net.minecraft.class_156;
import net.minecraft.class_333;
import net.minecraft.class_437;
import org.jetbrains.annotations.ApiStatus;

@ApiStatus.Internal
public class ConfigReloadingScreen extends class_437 {
    
    private class_437 parent;
    
    public ConfigReloadingScreen(class_437 parent) {
        super(class_333.field_18967);
        this.parent = parent;
    }
    
    @Override
    public boolean method_25422() {
        return false;
    }
    
    @Override
    public void method_25394(int int_1, int int_2, float float_1) {
        this.method_25434(0);
        if (!RecipeHelper.getInstance().arePluginsLoading())
            field_22787.method_1507(parent);
        this.method_25300(this.field_22793, class_1074.method_4662("text.rei.config.is.reloading"), this.field_22789 / 2, this.field_22790 / 2 - 50, 16777215);
        String string_3;
        switch ((int) (class_156.method_658() / 300L % 4L)) {
            case 0:
            default:
                string_3 = "O o o";
                break;
            case 1:
            case 3:
                string_3 = "o O o";
                break;
            case 2:
                string_3 = "o o O";
        }
        this.method_25300(this.field_22793, string_3, this.field_22789 / 2, this.field_22790 / 2 - 41, 8421504);
        super.method_25394(int_1, int_2, float_1);
    }
    
    @Override
    public boolean method_25421() {
        return false;
    }
}

==> RoughlyEnoughItems-4.3.6-unstable-sources.jar: me/shedaniel/rei/gui/ConfigReloadingScreen.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.gui;

import me.shedaniel.rei.api.RecipeHelper;
import net.minecraft.class_1074;
import net.minecraft.class_156;
import net.minecraft.class_333;
import net.minecraft.class_437;
import net.minecraft.class_4587;
import org.jetbrains.annotations.ApiStatus;

@ApiStatus.Internal
public class ConfigReloadingScreen extends class_437 {
    
    private class_437 parent;
    
    public ConfigReloadingScreen(class_437 parent) {
        super(class_333.field_18967);
        this.parent = parent;
    }
    
    @Override
    public boolean method_25422() {
        return false;
    }
    
    @Override
    public void method_25394(class_4587 matrices, int int_1, int int_2, float float_1) {
        this.method_25434(0);
        if (!RecipeHelper.getInstance().arePluginsLoading())
            field_22787.method_1507(parent);
        this.method_25300(matrices, this.field_22793, class_1074.method_4662("text.rei.config.is.reloading"), this.field_22789 / 2, this.field_22790 / 2 - 50, 16777215);
        String string_3;
        switch ((int) (class_156.method_658() / 300L % 4L)) {
            case 0:
            default:
                string_3 = "O o o";
                break;
            case 1:
            case 3:
                string_3 = "o O o";
                break;
            case 2:
                string_3 = "o o O";
        }
        this.method_25300(matrices, this.field_22793, string_3, this.field_22789 / 2, this.field_22790 / 2 - 41, 8421504);
        super.method_25394(matrices, int_1, int_2, float_1);
    }
    
    @Override
    public boolean method_25421() {
        return false;
    }
}
